@@ -1,3 +1,4 @@
+# pylint: disable = no-name-in-module
 # -*- coding: utf-8 -*-
 """
 :mod:`orion.algo.skopt.bayes` -- Perform bayesian optimization
@@ -37,7 +38,56 @@ def orion_space_to_skopt_space(orion_space):
 
 
 class BayesianOptimizer(BaseAlgorithm):
-    """Wrapper skopt's bayesian optimizer"""
+    """Wrapper skopt's bayesian optimizer
+
+    Parameters
+    ----------
+    space : ``orion.algo.space.Space``
+       Problem's definition
+    seed: int (default: None)
+       Seed used for the random number generator
+    strategy : str (default: cl_min)
+       Method to use to sample multiple points.
+       Supported options are ``["cl_min", "cl_mean", "cl_max"]``.
+       Check skopt docs for details.
+    n_initial_points : int (default: 10)
+       Number of evaluations of trials with initialization points
+       before approximating it with `base_estimator`. Points provided as
+       ``x0`` count as initialization points. If ``len(x0) < n_initial_points``
+       additional points are sampled at random.
+    acq_func : str (default: gp_hedge)
+       Function to minimize over the posterior distribution. Can be:
+       ``["LCB", "EI", "PI", "gp_hedge", "EIps", "PIps"]``. Check skopt
+       docs for details.
+    alpha : float or array-like (default: 1e-10)
+       Value added to the diagonal of the kernel matrix during fitting.
+       Larger values correspond to increased noise level in the observations
+       and reduce potential numerical issue during fitting. If an array is
+       passed, it must have the same number of entries as the data used for
+       fitting and is used as datapoint-dependent noise level. Note that this
+       is equivalent to adding a WhiteKernel with c=alpha. Allowing to specify
+       the noise level directly as a parameter is mainly for convenience and
+       for consistency with Ridge.
+    n_restarts_optimizer : int (default: 0)
+       The number of restarts of the optimizer for finding the kernel's
+       parameters which maximize the log-marginal likelihood. The first run
+       of the optimizer is performed from the kernel's initial parameters,
+       the remaining ones (if any) from thetas sampled log-uniform randomly
+       from the space of allowed theta-values. If greater than 0, all bounds
+       must be finite. Note that n_restarts_optimizer == 0 implies that one
+       run is performed.
+    noise: str (default: "gaussian")
+       If set to "gaussian", then it is assumed that y is a noisy estimate of f(x) where the
+       noise is gaussian.
+    normalize_y : bool (default: False)
+       Whether the target values y are normalized, i.e., the mean of the
+       observed target values become zero. This parameter should be set to
+       True if the target values' mean is expected to differ considerable from
+       zero. When enabled, the normalization effectively modifies the GP's
+       prior based on the data, which contradicts the likelihood principle;
+       normalization is thus disabled per default.
+
+    """
 
     requires_type = "real"
     requires_dist = "linear"
@@ -56,62 +106,6 @@ class BayesianOptimizer(BaseAlgorithm):
         noise="gaussian",
         normalize_y=False,
     ):
-        """Initialize skopt's BayesianOptimizer.
-
-        Copying documentation from `skopt.learning.gaussian_process.gpr` and
-        `skopt.optimizer.optimizer`.
-
-        Parameters
-        ----------
-        space : `orion.algo.space.Space`
-           Problem's definition
-        seed: int (default: None)
-           Seed used for the random number generator
-        strategy : str (default: cl_min)
-           Method to use to sample multiple points.
-           Supported options are `"cl_min"`, `"cl_mean"` or `"cl_max"`.
-           Check skopt docs for details.
-        n_initial_points : int (default: 10)
-           Number of evaluations of `func` with initialization points
-           before approximating it with `base_estimator`. Points provided as
-           `x0` count as initialization points. If len(x0) < n_initial_points
-           additional points are sampled at random.
-        acq_func : str (default: gp_hedge)
-           Function to minimize over the posterior distribution. Can be:
-           ``["LCB", "EI", "PI", "gp_hedge", "EIps", "PIps"]``. Check skopt
-           docs for details.
-        alpha : float or array-like (default: 1e-10)
-           Value added to the diagonal of the kernel matrix during fitting.
-           Larger values correspond to increased noise level in the observations
-           and reduce potential numerical issue during fitting. If an array is
-           passed, it must have the same number of entries as the data used for
-           fitting and is used as datapoint-dependent noise level. Note that this
-           is equivalent to adding a WhiteKernel with c=alpha. Allowing to specify
-           the noise level directly as a parameter is mainly for convenience and
-           for consistency with Ridge.
-        n_restarts_optimizer : int (default: 0)
-           The number of restarts of the optimizer for finding the kernel's
-           parameters which maximize the log-marginal likelihood. The first run
-           of the optimizer is performed from the kernel's initial parameters,
-           the remaining ones (if any) from thetas sampled log-uniform randomly
-           from the space of allowed theta-values. If greater than 0, all bounds
-           must be finite. Note that n_restarts_optimizer == 0 implies that one
-           run is performed.
-        noise: str (default: "gaussian")
-           If set to "gaussian", then it is assumed that y is a noisy estimate of f(x) where the
-           noise is gaussian.
-        normalize_y : bool (default: False)
-           Whether the target values y are normalized, i.e., the mean of the
-           observed target values become zero. This parameter should be set to
-           True if the target values' mean is expected to differ considerable from
-           zero. When enabled, the normalization effectively modifies the GP's
-           prior based on the data, which contradicts the likelihood principle;
-           normalization is thus disabled per default.
-
-        .. seemore::
-           About optional arguments passed to `skopt.learning.GaussianProcessRegressor`.
-
-        """
         if strategy is not None:
             log.warning("Strategy is deprecated and will be removed in v0.1.2.")
 
